==> handgpt-0.1.0.tar.gz: handgpt-0.1.0/README.md <==
# HandGPT

![HandGPT Logo](https://handgpt.app/logo.png)

HandGPT is an innovative tool designed for developing and testing Large Language Models (LLMs) to control devices such as smartphones and computers. The project combines software applications and intelligent hardware to empower LLMs to interact with devices through simulated vision and action.

- **GitHub Repository**: [HandGPT](https://github.com/handgpt/HandGPT)
- **iOS App**: [Download on App Store](https://apps.apple.com/us/app/handgpt/id6737915559)
- **Intelligent Hardware**: [Buy Now](https://handgpt.app)

---

## Key Features

- **Cross-Platform Support**: Start with iOS, with Android, macOS, and Windows apps in development.
- **Device Control via LLMs**: Enable LLMs to "see" the device screen and provide action commands.
- **Integrated Intelligent Hardware**: A compact Bluetooth mouse and keyboard combination that allows LLMs to interact with devices physically.
- **Developer-Friendly APIs**: Simplified APIs to facilitate quick development and testing of LLM-based agents for device control.
- **Customizable Agent Development**: Freedom to define agent capabilities and explore the performance of different models.

---

## Why HandGPT?

LLMs are poised to revolutionize productivity across industries, yet realizing practical applications remains challenging. HandGPT focuses on one of the most impactful and scalable AI applications—enabling AGI to control devices.

### Importance of Device Control

- **Massive Usage Potential**: Devices like smartphones dominate user interaction time and numbers, presenting unparalleled opportunities for AI.
- **Core AI Application**: Comparable in significance to embodied robotics, device control is a fundamental AI application.
- **Collaborative Innovation**: By uniting developers and fostering innovation, HandGPT aims to accelerate the integration of AI into daily life and generate significant societal and economic value.

---

## Challenges

While LLMs promise seamless device control, significant challenges remain:

1. **Spatial Understanding**:
   - LLMs exhibit advanced image recognition but lack mature spatial reasoning, critical for device control.

2. **Information Gain**:
   - Human instructions are often simple yet encode complex implicit information.
   - For example, a command like "move from A to B" in autonomous driving implies avoiding accidents, traffic violations, and battery depletion. Device control involves even more diverse and nuanced implicit information.

3. **Logical Reasoning**:
   - Effective device control demands robust reasoning capabilities, but longer reasoning chains increase error rates.

---

## Getting Started

### Installation and Usage
Please refer to the [Installation Guide](docs/installation.md) for detailed instructions on setting up the project and running your first agent.

### Intelligent Hardware Setup
For hardware setup and configuration, visit the [Hardware Guide](docs/hardware.md).

---

## Contributing

We welcome contributions to HandGPT! Please check out our [Contribution Guidelines](CONTRIBUTING.md) for information on how to get started.

---

## Support

- Join the discussion and share ideas in the [https://github.com/handgpt/HandGPT/discussions](https://github.com/handgpt/HandGPT/discussions).
- For questions or support, please contact our team at [github@handgpt.app](mailto:github@handgpt.app).

---

## License

HandGPT is licensed under the [MIT License](LICENSE.md). See the LICENSE file for more details.

---

## Intelligent Hardware

Purchase the intelligent hardware for full functionality:
[https://handgpt.app](https://handgpt.app)

==> handgpt-0.1.1.tar.gz: handgpt-0.1.1/README.md <==
# HandGPT

![HandGPT Logo](https://handgpt.app/logo.png)

HandGPT is an innovative tool designed for developing and testing Large Language Models (LLMs) to control devices such as smartphones and computers. The project combines software applications and intelligent hardware to empower LLMs to interact with devices through simulated vision and action.

- **GitHub Repository**: [HandGPT](https://github.com/handgpt/HandGPT)
- **iOS App**: [Download on App Store](https://apps.apple.com/us/app/handgpt/id6737915559)
- **Intelligent Hardware**: [Buy Now](https://handgpt.app)

---

## Key Features

- **Cross-Platform Support**: Start with iOS, with Android, macOS, and Windows apps in development.
- **Device Control via LLMs**: Enable LLMs to "see" the device screen and provide action commands.
- **Integrated Intelligent Hardware**: A compact Bluetooth mouse and keyboard combination that allows LLMs to interact with devices physically.
- **Developer-Friendly APIs**: Simplified APIs to facilitate quick development and testing of LLM-based agents for device control.
- **Customizable Agent Development**: Freedom to define agent capabilities and explore the performance of different models.

---

## Why HandGPT?

LLMs are poised to revolutionize productivity across industries, yet realizing practical applications remains challenging. HandGPT focuses on one of the most impactful and scalable AI applications—enabling AGI to control devices.

### Importance of Device Control

- **Massive Usage Potential**: Devices like smartphones dominate user interaction time and numbers, presenting unparalleled opportunities for AI.
- **Core AI Application**: Comparable in significance to embodied robotics, device control is a fundamental AI application.
- **Collaborative Innovation**: By uniting developers and fostering innovation, HandGPT aims to accelerate the integration of AI into daily life and generate significant societal and economic value.

---

## Challenges

While LLMs promise seamless device control, significant challenges remain:

1. **Information Gain**:
   - Human instructions are often simple yet encode complex implicit information.
   - For example, a command like "move from A to B" in autonomous driving implies avoiding accidents, traffic violations, and battery depletion. Device control involves even more diverse and nuanced implicit information.

2. **Spatial Understanding**:
   - LLMs exhibit advanced image recognition but lack mature spatial reasoning, critical for device control.

3. **Logical Reasoning**:
   - Effective device control demands robust reasoning capabilities, but longer reasoning chains increase error rates.

---

## Getting Started

### Installation and Usage
Install HandGPT using pip:

```bash
pip install handgpt
```

Refer to the [Getting Started Guide](docs/getting_started.md) for detailed setup instructions.

### Intelligent Hardware Setup
For hardware setup and configuration, visit the [Hardware Guide](docs/hardware.md).

---

## Examples

HandGPT provides example agents to help developers get started quickly. For instance, the [Post to Twitter](examples/official/post_to_twitter) example demonstrates how to automate posting tweets using an LLM-powered agent. Watch the demo video:

<iframe width="560" height="315" src="https://www.youtube.com/embed/9GSG7uFv8p8" title="Post to Twitter Demo" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe> example demonstrates how to automate posting tweets using an LLM-powered agent.

---

## Roadmap

- **Upcoming Features**:
  - Android, macOS, and Windows platform support.
  - Agent Marketplace: Allow developers to monetize their agents through a marketplace for end-users.
  - Identity NFTs: Assign unique identities to agents, akin to human identification.

- **Ongoing Development**:
  - Improving spatial reasoning and implicit information processing.
  - Enhancing LLM reasoning capabilities for complex control tasks.

---

## Contributing

We welcome contributions to HandGPT! Please check out our [Contribution Guidelines](CONTRIBUTING.md) for information on how to get started.

---

## Support

- Join the discussion and share your ideas in the [GitHub Discussions](https://github.com/handgpt/HandGPT/discussions).
- For questions or support, please contact our team at [github@handgpt.app](mailto:github@handgpt.app).

---

## License

HandGPT is licensed under the [MIT License](LICENSE.md). See the LICENSE file for more details.

---

## Intelligent Hardware

Purchase the intelligent hardware for full functionality:
[https://handgpt.app](https://handgpt.app)

---

## Acknowledgments

HandGPT is a collective effort by a passionate team dedicated to advancing AI applications. We thank our contributors and supporters for helping bring this vision to life.
